import { ArnFormat, Resource, ResourceProps } from 'aws-cdk-lib';
import { CfnWorkGroup } from 'aws-cdk-lib/aws-athena';
import { IConstruct } from 'constructs';
import { NamedQuery } from '.';
import { IAnalyticsEngine } from './lib/analytics-engine';
import { Database } from '../glue';
/**
 * Configuration for adding a NamedQuery to a WorkGroup.
 */
export interface AddNamedQueryOptions extends ResourceProps {
    /**
     * The Glue database to which the query belongs.
     *
     * @see [NamedQuery Database](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-namedquery.html#cfn-athena-namedquery-database)
     */
    readonly database: Database;
    /**
     * A human friendly description explaining the functionality of the query.
     *
     * @see [NamedQuery Description](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-namedquery.html#cfn-athena-namedquery-description)
     */
    readonly description?: string;
    /**
     * The name of the query.
     *
     * @see [NamedQuery Name](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-namedquery.html#cfn-athena-namedquery-name)
     */
    readonly name?: string;
    /**
     * The SQL statements that make up the query.
     *
     * @see [NamedQuery QueryString](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-namedquery.html#cfn-athena-namedquery-querystring)
     * @see [Athena SQL reference](https://docs.aws.amazon.com/athena/latest/ug/ddl-sql-reference.html)
     */
    readonly queryString: string;
}
export declare class WorkGroupState {
    readonly name: string;
    static readonly DISABLED: WorkGroupState;
    static readonly ENABLED: WorkGroupState;
    static of(name: string): WorkGroupState;
    private constructor();
}
export interface IWorkGroup {
    readonly workGroupArn: string;
    readonly workGroupCreationTime: string;
    readonly workGroupEffectiveEngineVersion: string;
    readonly workGroupName: string;
}
declare abstract class WorkGroupBase extends Resource implements IWorkGroup {
    abstract readonly workGroupArn: string;
    abstract readonly workGroupCreationTime: string;
    abstract readonly workGroupEffectiveEngineVersion: string;
    abstract readonly workGroupName: string;
    addNamedQuery(id: string, options: AddNamedQueryOptions): NamedQuery;
}
export interface WorkGroupAttributes {
    readonly arn?: string;
    readonly creationTime?: string;
    readonly effectiveEngineVersion?: string;
    readonly name?: string;
}
export interface WorkGroupOptions {
    readonly description?: string;
    readonly engine?: IAnalyticsEngine;
    readonly name?: string;
    readonly recursiveDelete?: boolean;
    readonly state?: WorkGroupState;
}
export interface WorkGroupProps extends ResourceProps, WorkGroupOptions {
}
export declare class WorkGroup extends WorkGroupBase {
    static readonly ARN_FORMAT: ArnFormat;
    static fromWorkGroupArn(scope: IConstruct, id: string, arn: string): IWorkGroup;
    static fromWorkGroupAttributes(scope: IConstruct, id: string, attrs: WorkGroupAttributes): IWorkGroup;
    static fromWorkGroupName(scope: IConstruct, id: string, name: string): IWorkGroup;
    readonly description?: string;
    readonly engine: IAnalyticsEngine;
    readonly name: string;
    readonly recursiveDelete: boolean;
    readonly state?: WorkGroupState;
    readonly resource: CfnWorkGroup;
    readonly workGroupArn: string;
    readonly workGroupCreationTime: string;
    readonly workGroupEffectiveEngineVersion: string;
    readonly workGroupName: string;
    constructor(scope: IConstruct, id: string, props: WorkGroupProps);
}
export {};
