import { Resource, ResourceProps, SecretValue } from 'aws-cdk-lib';
import { MetricOptions, Metric } from 'aws-cdk-lib/aws-cloudwatch';
import { CfnVPNConnection, IVpnConnection } from 'aws-cdk-lib/aws-ec2';
import { Construct } from 'constructs';
import { ILocalVpnEndpoint, IRemoteVpnEndpoint } from '.';
/**
 * Represents a VPN protocol that can be used to establish a connection.
 */
export declare class VpnConnectionType {
    readonly name: string;
    /**
     * The ipsec.1 VPN protocol.
     */
    static readonly IPSEC_1: VpnConnectionType;
    /**
     * An escape hatch method that allows defining custom VPN protocols.
     *
     * @param name The name of the VPN protocol.
     * @returns A VpnConnectionType object representing the specified protocol.
     */
    static of(name: string): VpnConnectionType;
    /**
     * Creates a new instance of the VpnConnectionType class.
     *
     * @param name The name of the VPN protocol.
     */
    private constructor();
}
export interface TunnelOptions {
    readonly preSharedKey?: SecretValue;
    readonly insideCidr?: string;
}
/**
 * Configuration for the VpnConnection resource.
 */
export interface VpnConnectionProps extends ResourceProps {
    readonly connectionType?: VpnConnectionType;
    readonly localEndpoint: ILocalVpnEndpoint;
    readonly remoteEndpoint: IRemoteVpnEndpoint;
    readonly staticRoutesOnly?: boolean;
    readonly tunnelConfigurations?: TunnelOptions[];
}
/**
 * Specifies a VPN connection between a virtual private gateway and a VPN
 * customer gateway or a transit gateway and a VPN customer gateway.
 */
export declare class VpnConnection extends Resource implements IVpnConnection {
    private readonly _tunnelConfigurations;
    readonly connectionType: VpnConnectionType;
    readonly localEndpoint: ILocalVpnEndpoint;
    readonly remoteEndpoint: IRemoteVpnEndpoint;
    readonly staticRoutesOnly?: boolean;
    get tunnelConfigurations(): TunnelOptions[];
    readonly resource: CfnVPNConnection;
    readonly vpnId: string;
    readonly customerGatewayId: string;
    readonly customerGatewayIp: string;
    readonly customerGatewayAsn: number;
    /**
       * Creates a new instance of the TransitGatewayAttachment class.
       *
       * @param scope A CDK Construct that will serve as this stack's parent in the construct tree.
       * @param id A name to be associated with the stack and used in resource naming. Must be unique
       * within the context of 'scope'.
       * @param props Arguments related to the configuration of the resource.
       */
    constructor(scope: Construct, id: string, props: VpnConnectionProps);
    metric(metricName: string, props?: MetricOptions): Metric;
    metricTunnelState(props?: MetricOptions): Metric;
    metricTunnelDataIn(props?: MetricOptions): Metric;
    metricTunnelDataOut(props?: MetricOptions): Metric;
    addTunnelConfiguration(options: TunnelOptions): void;
}
